@@ -1,11 +1,11 @@
 import sys
 from pathlib import Path
 
-__version__ = '1.9.2'
+from .config import *  # noqa: F403
 
-IS_FLATPAK = Path('/app/share/run-as-flatpak').exists()
+__version__ = "2.0.0"
 
-portable_path = Path(sys.executable).parent / 'is_portable'
+portable_path = Path(sys.executable).parent / "is_portable"
 IS_PORTABLE = portable_path.exists()
 
 # Check for Microsoft app identity by trying to query AppInfo.
@@ -13,9 +13,9 @@ IS_PORTABLE = portable_path.exists()
 has_ms_appinfo = False
 try:
     from winrt.windows.applicationmodel import AppInfo
-    _current_appinfo = AppInfo.current()  # type: ignore
-    has_ms_appinfo = True
-except (AttributeError, ImportError, OSError):
+
+    has_ms_appinfo = AppInfo.current is not None
+except Exception:
     pass
 
 IS_MS_STORE = has_ms_appinfo
