@@ -22,25 +22,27 @@ from typing import cast
 
 import gc
 import logging
+import multiprocessing
 import os
 import pprint
 import sys
 import weakref
 from collections import defaultdict
+from concurrent.futures import ProcessPoolExecutor
 
 from gi.repository import Gdk
 from gi.repository import GLib
 from gi.repository import GObject
-from nbxmpp.idlequeue import IdleQueue
 from nbxmpp.protocol import JID
+from nbxmpp.task import Task
 
 import gajim
-from gajim.common import config as c_config
 from gajim.common import configpaths
 from gajim.common import ged as ged_module
 from gajim.common import types
 from gajim.common.const import Display
 from gajim.common.i18n import get_default_lang
+from gajim.common.multiprocess import init_process
 
 if typing.TYPE_CHECKING:
     from gajim.common.call_manager import CallManager
@@ -57,13 +59,12 @@ if typing.TYPE_CHECKING:
     from gajim.gtk.main import MainWindow  # noqa: F401
 
 
-interface = cast(types.InterfaceT, None)
-config = c_config.Config()
 settings = cast(types.SettingsT, None)
 version = gajim.__version__
 connections: dict[str, types.Client] = {}
 avatar_cache: dict[str, dict[str, Any]] = {}
 bob_cache: dict[str, bytes] = {}
+services_cache: Any = None
 app = None  # type: GajimApplication
 window = None  # type: MainWindow
 commands = None  # type: ChatCommands
@@ -96,8 +97,6 @@ notification = None
 # list of our nick names in each account
 nicks: dict[str, str] = {}
 
-proxy65_manager = None
-
 cert_store = cast('CertificateStore', None)
 
 call_manager = cast('CallManager', None)
@@ -106,14 +105,12 @@ preview_manager = cast('PreviewManager', None)
 
 task_manager = cast('TaskManager', None)
 
-# These will be set in app.gui_interface.
-idlequeue = cast(IdleQueue, None)
-socks5queue = None
-
 gupnp_igd = None
 
 gsound_ctx = None
 
+process_pool = cast(ProcessPoolExecutor, None)
+
 _dependencies = {
     'FARSTREAM': False,
     'GST': False,
@@ -121,14 +118,25 @@ _dependencies = {
     'GEOCLUE': False,
     'UPNP': False,
     'GSOUND': False,
-    'GSPELL': False,
+    'SPELLING': False,
     'IDLE': False,
-    'APPINDICATOR': False,
-    'AYATANA_APPINDICATOR': False,
     'SENTRY_SDK': False,
 }
 
-_tasks: dict[int, list[Any]] = defaultdict(list)
+_tasks: dict[int, list[Task]] = defaultdict(list)
+
+
+def init_process_pool() -> None:
+    global process_pool
+
+    mp_context = multiprocessing.get_context("spawn")
+    process_pool = ProcessPoolExecutor(
+        max_workers=4,
+        mp_context=mp_context,
+        # https://github.com/python/cpython/issues/115634
+        # max_tasks_per_child=5,
+        initializer=init_process,
+    )
 
 
 def print_version() -> None:
@@ -211,9 +219,9 @@ def detect_dependencies() -> None:
         if _dependencies['GST'] and _dependencies['FARSTREAM']:
             conference = Gst.ElementFactory.make('fsrtpconference', None)
             conference.new_session(Farstream.MediaType.AUDIO)
-            from gajim.gtk.gstreamer import create_gtk_widget
-            gtk_widget = create_gtk_widget()
-            if gtk_widget is not None:
+            from gajim.gtk.gstreamer import create_video_elements
+            video_elements = create_video_elements()
+            if video_elements is not None:
                 _dependencies['AV'] = True
     except Exception as error:
         log('gajim').warning('AV dependency test failed: %s', error)
@@ -261,31 +269,17 @@ def detect_dependencies() -> None:
     except (ImportError, ValueError):
         pass
 
-    # GSPELL
+    # LIBSPELLING
     try:
-        gi.require_version('Gspell', '1')
-        from gi.repository import Gspell
-        langs = Gspell.language_get_available()
+        gi.require_version('Spelling', '1')
+        from gi.repository import Spelling
+        provider = Spelling.Provider.get_default()
+        langs = provider.list_languages()
         for lang in langs:
             log('gajim').info('%s (%s) dict available',
                               lang.get_name(), lang.get_code())
         if langs:
-            _dependencies['GSPELL'] = True
-    except (ImportError, ValueError):
-        pass
-
-    # APPINDICATOR
-    try:
-        gi.require_version('AppIndicator3', '0.1')
-        from gi.repository import AppIndicator3  # noqa: F401
-        _dependencies['APPINDICATOR'] = True
-    except (ImportError, ValueError):
-        pass
-    # AYATANA APPINDICATOR
-    try:
-        gi.require_version('AyatanaAppIndicator3', '0.1')
-        from gi.repository import AyatanaAppIndicator3  # noqa: F401
-        _dependencies['AYATANA_APPINDICATOR'] = True
+            _dependencies['SPELLING'] = True
     except (ImportError, ValueError):
         pass
 
@@ -557,11 +551,11 @@ def get_stored_bob_data(algo_hash: str) -> bytes | None:
     return None
 
 
-def register_task(self, task):
+def register_task(self: Any, task: Task) -> None:
     _tasks[id(self)].append(task)
 
 
-def remove_task(task, id_) -> None:
+def remove_task(task: Task, id_: int) -> None:
     try:
         _tasks[id_].remove(task)
     except Exception:
