@@ -11,9 +11,9 @@ from typing import overload
 import operator
 from collections.abc import Iterator
 from datetime import datetime
-from datetime import timezone
+from datetime import UTC
 
-import cairo
+from gi.repository import Gdk
 from gi.repository import GLib
 from nbxmpp.const import Affiliation
 from nbxmpp.const import Chatstate
@@ -22,6 +22,7 @@ from nbxmpp.const import Role
 from nbxmpp.namespaces import Namespace
 from nbxmpp.protocol import JID
 from nbxmpp.structs import DiscoInfo
+from nbxmpp.structs import HatData
 from nbxmpp.structs import LocationData
 from nbxmpp.structs import MucSubject
 from nbxmpp.structs import TuneData
@@ -31,8 +32,6 @@ from gajim.common import types
 from gajim.common.client_modules import ClientModules
 from gajim.common.const import PresenceShowExt
 from gajim.common.const import SimpleClientState
-from gajim.common.helpers import chatstate_to_string
-from gajim.common.helpers import get_groupchat_name
 from gajim.common.helpers import Observable
 from gajim.common.modules.base import BaseModule
 from gajim.common.modules.util import LogAdapter
@@ -49,6 +48,8 @@ from gajim.common.structs import MUCPresenceData
 from gajim.common.structs import PresenceData
 from gajim.common.structs import UNKNOWN_MUC_PRESENCE
 from gajim.common.structs import UNKNOWN_PRESENCE
+from gajim.common.util.muc import get_groupchat_name
+from gajim.common.util.user_strings import chatstate_to_string
 
 
 class ContactSettings:
@@ -145,11 +146,17 @@ class Contacts(BaseModule):
 
         contact = self._contacts.get(jid)
         if contact is not None:
-            if not isinstance(contact, GroupchatContact):
-                raise ValueError(f'Trying to add GroupchatContact {jid}, '
-                                 f'but contact already exists as {contact} '
-                                 f'(in roster: {contact.is_in_roster})')
-            return contact
+            if isinstance(contact, GroupchatContact):
+                return contact
+
+            self._log.error(f'Trying to add GroupchatContact {jid}, '
+                            f'but contact already exists as {contact} '
+                            f'(in roster: {contact.is_in_roster})')
+            # Most likely a groupchat which has been added to the roster.
+            # Remove jid from roster (if we are online) and delete contact.
+            if self._client.state.is_available:
+                self._client.get_module('Roster').delete_item(jid)
+            self._contacts.pop(jid)
 
         contact = GroupchatContact(self._log, jid, self._account)
 
@@ -338,7 +345,7 @@ class CommonContact(Observable, ClientModules):
             return False
 
         until = datetime.fromisoformat(mute_until)
-        is_muted = until > datetime.now(timezone.utc)
+        is_muted = until > datetime.now(UTC)
         if not is_muted:
             # Reset the setting to default
             GLib.idle_add(self.settings.set, 'mute_until', None)
@@ -513,6 +520,22 @@ class BareContact(CommonContact):
         assert self._jid.localpart is not None
         return self._jid.localpart
 
+    @property
+    def original_name(self) -> str:
+        if self._jid.is_domain:
+            assert self._jid.domain is not None
+            original_name = self._jid.domain
+        else:
+            assert self._jid.localpart is not None
+            original_name = self._jid.localpart
+
+        nickname = app.storage.cache.get_contact(
+            self._account, self._jid, 'nickname')
+        if nickname is not None:
+            original_name = nickname
+
+        return original_name
+
     def get_tune(self) -> TuneData | None:
         return self.get_module('UserTune').get_contact_tune(self._jid)
 
@@ -524,7 +547,7 @@ class BareContact(CommonContact):
         return app.storage.cache.get_contact(
             self._account, self._jid, 'avatar')
 
-    def set_avatar_sha(self, sha: str) -> None:
+    def set_avatar_sha(self, sha: str | None) -> None:
         app.storage.cache.set_contact(self._account, self._jid, 'avatar', sha)
 
     def get_avatar(self,
@@ -532,13 +555,14 @@ class BareContact(CommonContact):
                    scale: int,
                    add_show: bool = True,
                    default: bool = False,
-                   style: str = 'circle'):
+                   style: str = 'circle'
+                   ) -> Gdk.Texture:
 
         show = self.show.value if add_show else None
 
         transport_icon = self._get_transport_icon_name()
 
-        return app.app.avatar_storage.get_surface(
+        return app.app.avatar_storage.get_texture(
             self,
             size,
             scale,
@@ -554,7 +578,7 @@ class BareContact(CommonContact):
                 contact.update_presence(presence_data, notify=False)
         self.notify('presence-update')
 
-    def update_avatar(self, sha: str) -> None:
+    def update_avatar(self, sha: str | None) -> None:
         if self._avatar_sha == sha:
             return
 
@@ -623,7 +647,7 @@ class BareContact(CommonContact):
         return True
 
     @property
-    def type_string(self) -> str:
+    def type_string(self) -> Literal['chat']:
         return 'chat'
 
     @property
@@ -782,6 +806,7 @@ class GroupchatContact(CommonContact):
         contact.connect('user-left', self._on_user_signal)
         contact.connect('user-affiliation-changed', self._on_user_signal)
         contact.connect('user-role-changed', self._on_user_signal)
+        contact.connect('user-hats-changed', self._on_user_signal)
         contact.connect('user-status-show-changed', self._on_user_signal)
         contact.connect('user-avatar-update', self._on_user_signal)
         return contact
@@ -802,17 +827,29 @@ class GroupchatContact(CommonContact):
         client = app.get_client(self._account)
         return get_groupchat_name(client, self._jid)
 
+    @property
+    def original_name(self) -> str:
+        assert self._jid.localpart is not None
+        original_name = self._jid.localpart
+
+        disco_info = app.storage.cache.get_last_disco_info(self._jid)
+        if disco_info is not None:
+            if disco_info.muc_name:
+                original_name = disco_info.muc_name
+
+        return original_name
+
     @property
     def avatar_sha(self) -> str | None:
         return app.storage.cache.get_muc(self._account, self._jid, 'avatar')
 
-    def set_avatar_sha(self, sha: str) -> None:
+    def set_avatar_sha(self, sha: str | None) -> None:
         app.storage.cache.set_muc(self._account, self._jid, 'avatar', sha)
 
-    def get_avatar(self, size: int, scale: int) -> cairo.ImageSurface:
+    def get_avatar(self, size: int, scale: int) -> Gdk.Texture:
         transport_icon = self._get_transport_icon_name()
 
-        return app.app.avatar_storage.get_muc_surface(
+        return app.app.avatar_storage.get_muc_texture(
             self._account,
             self._jid,
             size,
@@ -898,7 +935,7 @@ class GroupchatContact(CommonContact):
         return all_ or room
 
     @property
-    def type_string(self) -> str:
+    def type_string(self) -> Literal['groupchat']:
         return 'groupchat'
 
     def has_composing_participants(self) -> bool:
@@ -1017,10 +1054,10 @@ class GroupchatParticipant(CommonContact):
                    scale: int,
                    add_show: bool = True,
                    style: str = 'circle'
-                   ) -> cairo.ImageSurface:
+                   ) -> Gdk.Texture:
 
         show = self.show.value if add_show else None
-        return app.app.avatar_storage.get_surface(
+        return app.app.avatar_storage.get_texture(
             self, size, scale, show, style=style)
 
     def update_presence(self, presence: MUCPresenceData) -> None:
@@ -1031,7 +1068,7 @@ class GroupchatParticipant(CommonContact):
         self.notify('user-avatar-update')
 
     @property
-    def type_string(self) -> str:
+    def type_string(self) -> Literal['pm']:
         return 'pm'
 
     @property
@@ -1044,6 +1081,10 @@ class GroupchatParticipant(CommonContact):
         assert data is not None
         return data.nick == self.name
 
+    @property
+    def hats(self) -> HatData | None:
+        return self._presence.hats
+
 
 def can_add_to_roster(
     contact: BareContact | GroupchatContact | GroupchatParticipant
