@@ -1,16 +1,6 @@
 # This file is part of Gajim.
 #
-# Gajim is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published
-# by the Free Software Foundation; version 3 only.
-#
-# Gajim is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with Gajim.  If not, see <http://www.gnu.org/licenses/>.
+# SPDX-License-Identifier: GPL-3.0-only
 
 # XEP-0363: HTTP File Upload
 
@@ -20,7 +10,6 @@ from typing import cast
 
 import mimetypes
 import os
-import tempfile
 from collections import defaultdict
 from collections.abc import Callable
 from pathlib import Path
@@ -41,18 +30,19 @@ from nbxmpp.task import Task
 from nbxmpp.util import convert_tls_error_flags
 
 from gajim.common import app
+from gajim.common import configpaths
 from gajim.common import types
 from gajim.common.const import FTState
 from gajim.common.events import HTTPUploadError
 from gajim.common.events import HTTPUploadStarted
 from gajim.common.exceptions import FileError
 from gajim.common.filetransfer import FileTransfer
-from gajim.common.helpers import get_random_string
-from gajim.common.helpers import get_tls_error_phrases
 from gajim.common.i18n import _
 from gajim.common.modules.base import BaseModule
 from gajim.common.structs import OutgoingMessage
 from gajim.common.util.http import create_http_request
+from gajim.common.util.text import get_random_string
+from gajim.common.util.user_strings import get_tls_error_phrases
 
 
 class HTTPUpload(BaseModule):
@@ -180,14 +170,9 @@ class HTTPUpload(BaseModule):
         if state.is_finished:
             uri = transfer.get_transformed_uri()
 
-            type_ = 'chat'
-            if transfer.is_groupchat:
-                type_ = 'groupchat'
-
             message = OutgoingMessage(account=transfer.account,
                                       contact=transfer.contact,
-                                      message=uri,
-                                      type_=type_,
+                                      text=uri,
                                       oob_url=uri)
 
             self._client.send_message(message)
@@ -233,8 +218,8 @@ class HTTPUpload(BaseModule):
             filename=transfer.filename,
             size=transfer.size,
             content_type=transfer.mime,
-            callback=self._received_slot,
-            user_data=transfer)
+            callback=self._received_slot,  # type: ignore
+            user_data=transfer)  # type: ignore
 
     def _received_slot(self, task: Task) -> None:
         transfer = cast(HTTPFileTransfer, task.get_user_data())
@@ -317,6 +302,8 @@ class HTTPUpload(BaseModule):
             if request.get_error() == HTTPRequestError.CANCELLED:
                 self._log.info('Upload cancelled')
             else:
+                if not error:
+                    error = _('Upload could not be completed.')
                 transfer.set_error('http-response', error)
             return
 
@@ -343,7 +330,8 @@ class HTTPFileTransfer(FileTransfer):
     _errors = {
         'unsecure': _('The server returned an insecure transport (HTTP).'),
         'encryption-not-available': _('There is no encryption method available '
-                                      'for the chosen encryption.')
+                                      'for the chosen encryption.'),
+        'unknown': _('Unknown error.')
     }
 
     def __init__(self,
@@ -432,12 +420,12 @@ class HTTPFileTransfer(FileTransfer):
 
     @staticmethod
     def _get_temp_path() -> Path:
-        tempdir = tempfile.gettempdir()
-        return Path(tempdir) / get_random_string(16)
+        tempdir = configpaths.get_temp_dir()
+        return tempdir / get_random_string(16)
 
     def set_error(self, domain: str, text: str = '') -> None:
         if not text:
-            text = self._errors[domain]
+            text = self._errors.get(domain) or self._errors['unknown']
 
         super().set_error(domain, text)
         self._cleanup()
