@@ -31,10 +31,11 @@ class UserNickname(BaseModule):
 
     @event_node(Namespace.NICK)
     def _nickname_received(self,
-                           _con: types.xmppClient,
+                           _con: types.NBXMPPClient,
                            _stanza: Any,
                            properties: MessageProperties
                            ) -> None:
+        assert properties.pubsub_event is not None
         if properties.pubsub_event.retracted:
             return
 
@@ -45,6 +46,7 @@ class UserNickname(BaseModule):
             app.nicks[self._account] = nick
             return
 
+        assert properties.jid is not None
         app.storage.cache.set_contact(
             self._account, properties.jid, 'nickname', nick)
 
