@@ -1,3 +1,7 @@
+# This file is part of Gajim.
+#
+# SPDX-License-Identifier: GPL-3.0-or-later
+
 import unittest
 
 from gajim.common.const import URIType
@@ -19,5 +23,5 @@ class Test(unittest.TestCase):
             self.assertIn(t, _xmpp_uri_context_menus)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     unittest.main()
